'Programm ......... : TWI-Master fr eine LCD-Ansteuerung (Textausgabe)
'
'Programminhalt ... : - Beispielprogramm fr eine Masterbaugruppe (TWI)
'                       TWI-Buskopplung eines LCD-Modul (2x 16 Zeichen)
'                       Im Datenbereich der Slave-Baugruppe sind die Meldungen
'                       hinterlegt, die nach dem Senden von dieser angezeigt
'                       werden.
'
'Programmierer .... : Ingolf Bauer (ingolf.bauer@nexgo.de)
'Version .......... : V 1.1.90
'Datum ............ : 23.01.2012
'
'-------------------------------------------------------------------------------
'
'Simulator-Einstellmglichkeit
'-----------------------------
'$sim                                              'Wartezeit aus
'
' Achtung!
' Diese Zeile unbedingt auskommentieren, bevor der AVR programmiert wird, da
' sonst der AVR nicht korrekt arbeitet.
' Die Aktivierung ist nur fr den Simulator vorgesehen.
'
'-------------------------------------------------------------------------------
'
'Information
'-----------
'23.01.2012 - Nach einer neuen Programmierung ist es unbedingt erforderlich,
'             dass alle am TWI-Bus angeschlossenen AVR abgeschaltet und wieder
'             neu eingeschaltet werden.
'
'-------------------------------------------------------------------------------
'
'Versionsbersicht
'-----------------
'
'
'
'
'V 1.1.90  23.01.2012 - nderung .... : - Anpassung fr den Slave TSL
'V 1.0.99  10.01.2012 - Information . : - Beginn der Softwareentwicklung
'- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
'
'Programmspeicher des MCs (Programm-Flashspeicher): V 1.1.90 - 5%
'
'-------------------------------------------------------------------------------
'
'Informationen zur Software
'--------------------------
' Inhalt                                          | Zeile | Korrekturwert
'------------------------------------------------------------------------
' 01. Allgemeine Informationen .................. |  100  |
'      Taktfrequenz ............................. |  102  |
'      Programmierung ........................... |  108  |
' 02. Abkrzungsbersicht ....................... |  115  |
' 03. Compilereinstellungen ..................... |  119  |
' 04. Funktionsbeschreibung ..................... |  142  |
'      Allgemeines .............................. |  144  |
' 05. Interrupt ................................. |  153  |
' 06. Einstellung der FUSE- und/oder LOOK-Bits .. |  157  |
' 07. Anschluschema fr den AVR (ATmega16) ..... |  167  |
' 08. I/O-Ports ................................. |  195  |
' 09. Steckverbinder ............................ |  275  |
' 10. Definition ................................ |  281  |
'      Schaltkreis .............................. |  283  |
'      Schnittstelle ............................ |  288  |
'      Compilereinstellungen .................... |  292  |
' 11. Deklaration ............................... |  300  |
'      Bibliothek ............................... |  302  |
'      Subrotine (Call) ......................... |  310  |
'      optional - LCD-Ausgabe ................... |  314  |
'      Feld ..................................... |  320  |
'      Flag ..................................... |  323  |
'      Variable ................................. |  326  |
'      Zhler ................................... |  320  |
' 12. Konfiguration ............................. |  338  |
'      I/O-Port ................................. |  340  |
'      Timer .................................... |  368  |
'      optional - LCD ........................... |  381  |
'      Interrupt ................................ |  391  |
' 13. Alias ..................................... |  401  |
' 14. Initialisierung ........................... |  407  |
' 20. Programm .................................. |  470  |
'      Datenbertragung ......................... |  473  |
' 30. Unterprogramm ............................. |  502  |
' 40. Interrupt ................................. |  508  |
'      Timer 1 .................................. |  511  |
'       Zeitzhler .............................. |  520  |
'       Lebensbit ............................... |  528  |
' 50. Unterprogramm-Call ........................ |  541  |
'      Daten an den Slave senden ................ |  544  |
'      optional - LCD-Modul: Ausgabe ............ |  584  |
' 60. Funktion .................................. |  606  |
' 70. Datenbereich .............................. |  612  |





'01. Allgemeine Informationen
'----------------------------
'Taktfrequenz
' Als Taktfrequenz wir eine Quarzfrequenz von 16,0 MHz verwendet.
' Werden die Bedingungen (die der TWI-Bus erfordert) eingehalten, kann auch
' mit einer geringeren Frequenz getaktet werden. Die Timer-Einstellungen sind
' dann anzupassen.
'
'Programmierung
' Die Programmierung der MC kann extern oder ber die vorhandene Schnittstelle
' erfolgen.
' Zur Programmierung wurde das Modul "USBasp" verwendet, welches ber eine
' USB-Schnittstelle angeschlossen wird. Es kann direkt ber eine, in BASCOM
' integrierte Einstellung angesprochen werden.
'
'02. Abkrzungsbersicht
'-----------------------
' TWI ... : Two-wire Serial Interface (entspricht technisch dem I2C-Bus)

'03. Compilereinstellungen
'-------------------------
' Hinweise fr ATmega8/ATmega16 mit 1024 Byte SRAM
' Quelle:
' //halvar.at/elektronik/kleiner_bascom_avr_kurs/speicher_hwstack_swstack_frame/
'
' HW-Stack    - Empfehlung: 40 Byte bei INT, sonst 10 Byte ausreichend
'  32 Byte fr INT + je GOSUB 2 Byte, wenn bei INT ein GOSUB erfolgt
'  (bei Verschachtelung ... + n x 2 Byte)
'
' SW-Stack    - Empfehlung: 32 Byte (recht komplexe Aufrufe werden abgedeckt)
'   2 Byte fr jede bergebene Variable einer GOSUB-Routine + 2 Byte fr jede
'   LOCAL-Variable innerhalb einer GOSUB
'   (bei Verschachtelung ... n x 2 Byte)
'
' Frame-Space - Empfehlung: 60 Byte sollten alles abdecken
'                           (bei wenig Speicherverkleinern)
'  Beispiel:
'   2 x BYTE        =  2 Byte (erster und zweiter Parameter)
'   1 x WORD        =  2 Byte (dritte Parameter)
'   1 x STRING * 10 = 11 Byte (inkl. Abschlussbyte; vierter Parameter)
'   3 x BYTE        =  3 Byte (lokale Variablen)
'
'04. Funktionsbeschreibung
'-------------------------
' Allgemeines
' -----------
' Die Hardware fr die Master-Baugruppe wurde auf einem Testboard aufgebaut.
' Beim Anschluss des Microkontrollers gibt es keine Besonderheiten zu beachten.
' Die Takterzeugung erfolgt mitg einem Quarz, die Programmierung ber die SPI-
' Schnittstelle. Am Port C.2 ist eine LED fr die Anzeige des "Lebensbits" und
' an Port C.3 eine LED fr die Anzeige "Fehler bei der Datenbertragung" ange-
' schlossen.
'
'05. Interrupt
'-------------
' Timer 1: 16 Bit, Interrupt bei berlauf (Zeitbasis)
'
'06. Einstellung der FUSE- und/oder LOOK-Bits
'--------------------------------------------
' Fr die Einstellung der Fuse- und Lookbits ist der Bauanleitung ein "screen-
' shot" (Programmer: USBasp) beigelegt.
'
' /// Achtung ///
' Beim ATmega16 wird das JTAG(EN) Flag defaultmig auf Enable gesetzt. Dies
' bedeutet, dass das JTAG-Interface (prozenahe Datenabfrage) aktiviert ist.
' Dann kann aber Port C fr keine anderen Aufgaben genutzt werden!
'
'07. Anschluschema fr den AVR ATmega16
'---------------------------------------
'
'                   -----------------|_|-----------------
'                  | 1 [PB0]                     [PA0] 40|
'                  | 2 [PB1]                     [PA1] 39|
'                  | 3 [PB2, INT2]               [PA2] 38|
'                  | 4 [PB3, OC0]                [PA3] 37|
'                  | 5 [PB4]                     [PA4] 36|
' [~]   MOSI  ---> | 6 [PB5, MOSI]               [PA5] 35|
' [~]   MISO  <--- | 7 [PB6, MISO]               [PA6] 34|
' [~]   SCK   ---> | 8 [PB7, SCK]                [PA7] 33|
' [~]  /Reset ---> | 9 [/Reset]                 [AREF] 32| ==== P5V
'         P5V ==== |10 [VCC]                    [AGND] 31| ==== GND
'         GND ==== |11 [GND]                    [AVCC] 30| ==== P5V
'          QZ ++++ |12 [XTAL2]                   [PC7] 29|
'          QZ ++++ |13 [XTAL1]                   [PC6] 28|
'                  |14 [PD0, RXD]                [PC5] 27|
'                  |15 [PD1, TXD]                [PC4] 26|
'                  |16 [PD2, INT0]               [PC3] 25| ---> LED_2  [0]
'                  |17 [PD3, INT1]               [PC2] 24| ---> LED_1  [0]
'                  |18 [PD4]                [SDA, PC1] 23| ---> SDA    [B]
'                  |19 [PD5]                [SCL, PC0] 22| ---> SCL    [B]
'                  |20 [PD6]                     [PD7] 21|
'                   -------------------------------------
' Werte in []: Einstellungen nach dem Programmstart
'  ~: Impuls   0: aus   1: ein   B: Bussystem

'08. I/O-Ports
'-------------
' /Reset  : Resetfunktion
' LED_    : Anschluss fr LED
' SDA     : Busanschluss (Daten)
' SLC     : Busanschluss (Takt)
'
' _x      : Nummer fr LED (x: 1, 2)
'
' P5V     : Stromversorgung P 5V
' GND     : Stromversorgung Masse
'
' MISO    : Programmieranschlu
' MOSI    : Programmieranschlu
' QZ      : Anschlu Quarz
' SCK     : Programmieranschlu

'           Funktion     | Signal        | Erluterung                    | Pin
' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' -   : SV  P5V ........ | ............. | Stromversorgung .............. | 10
' -   : SV  GND ........ | ............. | Stromversorgung .............. | 11
' -   : SV  P5V ........ | ............. | Stromversorgung .............. | 30
' -   : SV  GND ........ | ............. | Stromversorgung .............. | 31
' -   : SV  P5V ........ | ............. | Referenzspannung ............. | 32
' -   : PRG /Reset ..... | ............. | Programmierung/Reset des MCs . |  9
' -   : QZ  Frequenz ... | ............. | Frequenznormal mit Quarz ..... | 12
' -   : QZ  Frequenz ... | ............. | Frequenznormal mit Quarz ..... | 13

' Port A    Funktion     | Signal        | Erluterung                    | Pin
' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' - .0: ..  ............ | ............. | .............................. | 40
' - .1: ..  ............ | ............. | .............................. | 39
' - .2: ..  ............ | ............. | .............................. | 38
' - .3: ..  ............ | ............. | .............................. | 37
' - .4: ..  ............ | ............. | .............................. | 36
' - .5: ..  ............ | ............. | .............................. | 35
' - .6: ..  ............ | ............. | .............................. | 34
' - .7: ..  ............ | ............. | .............................. | 33
'
'Port B     Funktion     | Signal        | Erluterung                    | Pin
' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' - .0: ..  ............ | ............. | .............................. |  1
' - .1: ..  ............ | ............. | .............................. |  2
' - .2: ..  ............ | ............. | .............................. |  3
' - .3: ..  ............ | ............. | .............................. |  4
' - .4: ..  ............ | ............. | .............................. |  5
' - .5: PRG MOSI ....... | MOSI ........ | Programmierung ............... |  6
' - .6: PRG MISO ....... | MISO ........ | Programmierung ............... |  7
' - .7: PRG SCK ........ | SCK ......... | Programmierung ............... |  8
'
'Port C     Funktion     | Signal        | Erluterung                    | Pin
' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' - .0: B   Takt  (Bus . | SLC ......... | TWI-Bussystem ................ | 22
' - .1: B   Daten (Bus). | SDA ......... | TWI-Bussystem ................ | 23
' - .2: DA  Anzeige .... | LED_1 ....... | Anzeige (Start, Lebensbit) ... | 24
' - .3: DA  Anzeige .... | LED_2 ....... | Anzeige (Busfehler) .......... | 25
' - .4: ..  ............ | ............. | .............................. | 26
' - .5: ..  ............ | ............. | .............................. | 27
' - .6: ..  ............ | ............. | .............................. | 28
' - .7: ..  ............ | ............. | .............................. | 29
'
'Port D     Funktion     | Signal        | Erluterung                    | Pin
' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' - .0: ..  ............ | ............. | .............................. | 14
' - .1: ..  ............ | ............. | .............................. | 15
' - .2: ..  ............ | ............. | .............................. | 16
' - .3: ..  ............ | ............. | .............................. | 17
' - .4: ..  ............ | ............. | .............................. | 18
' - .5: ..  ............ | ............. | .............................. | 19
' - .6: ..  ............ | ............. | .............................. | 20
' - .7: ..  ............ | ............. | .............................. | 21
'
'Erluterung
' B  : Bussystem
' DA : digitaler Ausgang
' DE : digitaler Eingang
' PRG: Programmierung
' QZ : Quarzanschluss
' SV : Stromverssorgung
'
'09. Steckverbinder
'------------------
' (entfllt)
'
'-------------------------------------------------------------------------------
'
'10. Definition
'--------------
'Schaltkreis
'-----------
   $regfile = "m16adef.dat"                       'Prozessor ....... : ATmega16A
   $crystal = 16000000                            'Quarzfrequenz ... : 16,0 MHz

'Schnittstelle
' ggf. fr eine Ausgabe im Simulator-Feld UART
'  $baud = 9600                                   'Baudrate ........ : 9600
                                                  '9600/19200/38400/57600/115200
'Compilereinstellung
'-------------------
   $hwstack = 40                                  'Hardware Stack
   $swstack = 32                                  'Software Stack
   $framesize = 60                                'Frame Space
'
'-----------------------------------------------------------------------------
'
'11. Deklaration
'---------------
'Bibliothek (Betriebsart: TWI)
' Die Bibliothek ist Bestandteil von BASCOM.
'
' /// Achtung ///
' Wird sie verwendet, bleibt der in BASCOM integrierte Simulator bei dem Befehl
' "I2CSTOP" stehen. => zum Testen auskommentieren!
   $lib "i2c_twi.lbx"

'Subrotinen (Call)
' Master-Daten senden
   Declare Sub Senden(slv_adr As Byte , Slv_wert() As Byte)

'optional - LCD-Ausgabe
' bei einem zustzlich angeschlossenen Modul am Port A
' L_Code : 0-CLS, 1/2-Zeile
' L_Text : Inhalt der Textausgabe
'   Declare Sub Cup_lcd(byval L_code As Byte , Byval L_text As String * 16 )

'Feld
   Dim Slv_wert(5)as Byte                         'Array (5)

'Flag
   Dim F_lb As Bit                                'Lebensbit

'Variable
   Dim Slv_adr As Byte                            'Slave_Adresse
   Dim T_twi As Byte                              'Wartezeit Datenbertragung

'Zhler
   Dim Z_t1 As Byte                               'Zeit T1
   Dim Z_lb As Byte                               'Zeit T1 (Lebensbit)

   Dim Hz01 As Byte                               'Hilfszhler 01
'
'-------------------------------------------------------------------------------
'
'12. Konfiguration
'-----------------
'I/O-Port
'--------
'=Port A
'-Datenrichtung (Ein [0]: Eingang, Aus [1]: Ausgang)
   Ddra = &B1111_1111                             'PA0-7 Aus
'-Pullup-Widerstand (passiv [0], aktiv [1])
   Porta = &B0000_0000                            'PA0-7 passiv
'- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
'=Port B
'-Datenrichtung (Ein [0]: Eingang, Aus [1]: Ausgang)
   Ddrb = &B1111_1111                             'PB0-7 Aus
'-Pullup-Widerstand (passiv [0], aktiv [1])
   Portb = &B0000_0000                            'PB0-7 passiv
'- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
'=Port C
'-Datenrichtung (Ein [0]: Eingang, Aus [1]: Ausgang)
   Ddrc = &B0000_1111                             'PC0-3 Aus; PC4-7 Ein
'-Pullup-Widerstand (passiv [0], aktiv [1])
   Portc = &B1111_0000                            'PC0-4 passiv; PC5-7 aktiv
'- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
'=Port D
'-Datenrichtung (Ein [0]: Eingang, Aus [1]: Ausgang)
   Ddrd = &B1111_1111                             'PD0-7 Aus
'-Pullup-Widerstand (passiv [0], aktiv [1])
   Portd = &B0000_0000                            'PD0-7 passiv
'
'-------------------------------------------------------------------------------
'
'Timer
'-----
'Timer: Normal-Konfiguration (Zeitbasis fr Kodierung; 1-8-64-256-1024)
'       Der Timerinterrupt 1 wird beim Timerberlauf ausgelst.
'                                   PSC  TVE   T      f
' T1 = 1/ Quarz* Teiler (1/ 16 MHz* 256* 625 = 10 ms; 100 Hz)

'Timer1 voreinstellen auf Wert: 65536-TVE
   Config Timer1 = Timer , Prescale = 256         'Konfiguration
      Timer1 = 64911                              'Voreinstellung
'
'-------------------------------------------------------------------------------
'
'optional - LCD
'--------------
'-LCD-Typ ..... : 2 Zeilen, 16 Zeichen
'   Config Lcd = 16 * 2
'   Config Lcdpin = Pin , Db4 = Porta.2 , Db5 = Porta.3 , Db6 = Porta.4 , _
'          Db7 = Porta.5 , E = Porta.0 , Rs = Porta.1
'   Cls                                            'Anzeige lschen
'
'-------------------------------------------------------------------------------
'
'Interrupt
'---------
   Enable Timer1                                  'Timer 1: Interrupt
      On Timer1 Int_tim1                          'Timer 1: berlauf

   Enable Interrupts                              'Interrupts: global zulassen
'
'-------------------------------------------------------------------------------
'
'
'13. Alias
'---------
' (nicht verwendet)
'
'-------------------------------------------------------------------------------
'
'14. Initialisierung
'-------------------
'Restart bei Zeitberschreitung
M_restart:

'Festlegung der Kanle fr die TWI-Betriebsart
   Config Scl = Portc.0                           'Kanal fr SCL (Port C.0)
   Config Sda = Portc.1                           'Kanal fr SDA (Port C.1)

   I2cinit                                        'I2C-Pins initialisieren
                                                  'auch nach PORT/DDR wichtig

'Setzt in Abhngigkeit der Taktfrequenz die Register TWSR und TWBR
   Config Twi = 400000                            'Busfrequenz: 400 kHz
'
'-------------------------------------------------------------------------------
'
'Lebensbit deaktivieren
   F_lb = 0

'Blinken beim Programmstart (nach einem Reset)
   For Hz01 = 1 To 6
      Portc.2 = Not Portc.2                       'LED_gn (3x)
      Waitms 300
   Next Hz01

'optional - LCD-Anzeige: Ausgabe der Softwareinformation (Version der Firmware)
'   Call Cup_lcd(0 , " " )                         'LCD lschen
'   Call Cup_lcd(1 , "Amatronik - ULS " )          'LCD-Ausgabe, Zeile 1
'   Call Cup_lcd(2 , "Version: 1.1.90 " )          'LCD-Ausgabe, Zeile 2

'   Wait 3                                         'Anzeige

'optional - Anzeig
'   Call Cup_lcd(0 , " " )                         'LCD lschen
'   Call Cup_lcd(1 , "Initialisierung " )          'LCD-Ausgabe, Zeile 1

'Wartezeit zum Starten aller Buskomponenten
   Wait 10

'Lebensbit aktivieren
   F_lb = 1

'Wartezeit nach einer Datenbertragung zur Fehlerreduzierung
' Sie wird im Programm automatisch korrigiert
' 13.01.2012: sich einstellender Wert auf dem Testboard: 11
   T_twi = 5
'
'-------------------------------------------------------------------------------
'
'Slave (LCD_&H50)
'----------------
   Slv_adr = &H50                                 'Slave-Adresse ... :  50 Hex
   Slv_wert(1) = 2                                'Byte-Anzahl ..... :   2

'Testeintrag (Werte den Feldelementen zuweisen)
   Slv_wert(2) = 1                                'Byte-Wert(1)
   Slv_wert(3) = 2                                'Byte-Wert(2)
   Slv_wert(4) = 3                                'Byte-Wert(3)
   Slv_wert(5) = 4                                'Byte-Wert(4)
'
'-------------------------------------------------------------------------------
'
'20. Programm
'------------
Do
'Datenbertragung
'----------------
'Index der Meldung initialisieren
'- alle Meldungen werden nacheinander aufgerufen
   If Slv_wert(2) < 9 Then
      Incr Slv_wert(2)                            'Index zuweisen
   Else
      Slv_wert(2) = 2
   End If

   Disable Timer1                                 'Interrupt deaktivieren
      Call Senden(slv_adr , Slv_wert(5))          'Elemente fr Call
   Enable Timer1                                  'Interrupt aktivieren

'optional
'   Cls : Lcd Slv_wert(2)

'Wartezeit bis zur nchsten bertragung
   Wait 2

'Ende Programmschleife
Loop

'Ende Programm
End

'===============================================================================

'-------------------------------------------------------------------------------
'30. === U N T E R P R O G R A M M =============================================
'-------------------------------------------------------------------------------

'entfllt

'-------------------------------------------------------------------------------
'40. === I N T E R R U P T R O U T I N E =======================================
'-------------------------------------------------------------------------------

'Timer 1
'-------
Int_tim1:
'T1 = 1/ Quarz* Teiler (1/ 16 MHz* 256* 625 = 10,00 ms; 100 Hz)
'Interrupt: Timer 1 (16 Bit), alle 10 ms

'Voreinstellung des Zhlers
   Timer1 = 64911                                 'Voreinstellung (10 ms)

'Zeitzhler
   Incr Z_t1                                      'Zhler: Zeit (allgemein)
   Incr Z_lb                                      'Zhler: Lebensbit

   If Z_t1 = 10 Then                              'Rcksetzen alle 100 ms
      Z_t1 = 0
   End If

'Lebensbit (100 ms)
   If F_lb = 1 Then                               'erst nach der Startroutine
      Select Case Z_lb
         Case 0
            Portc.2 = 1                           'LED_gn Ein
         Case 15
            Portc.2 = 0                           'LED_gn Aus
      End Select
   End If

Return

'-------------------------------------------------------------------------------
'50. === U N T E R P R O G R A M M - C A L L ===================================
'-------------------------------------------------------------------------------

'Daten an den Slave senden
'-------------------------
Sub Senden(slv_adr As Byte , Slv_wert())
'I2C_Slave: Byte senden (Adresse, Array(5))
   I2cstart                                       'Start Senden
'Slave-Adresse
      I2cwbyte Slv_adr
'Slave_Daten
      I2cwbyte Slv_wert(1)                        'Byte 1 (Anzahl Datenbytes)

      For Hz01 = 2 To Slv_wert(1)                 'Byte 2 bis Anzahl laut Aufruf
          I2cwbyte Slv_wert(hz01)                 'Daten (Array) senden
         Next Hz01
   I2cstop                                        'Stop senden

'Wartezeit fr eine fehlerfreie Datenbertragung
' Wenn gehuft Fehler auftreten, wird diese Zeit erhht.
   Waitus T_twi

'Fehlerbehandlung (Datenbus-bertragung)
   If Err <> 0 Then
      Incr T_twi                                  'Wartezeit erhhen
      Portc.3 = 1 : Waitms 500 : Portc.3 = 0      'LED_rt: 500 ms
   End If

'Restart:
   If T_twi > 30 Then
'Wartezeit zum Starten aller Buskomponenten
'optional
'      Call Cup_lcd(0 , " " )                      'LCD lschen
'      Call Cup_lcd(1 , "<- Busfehler -> " )       'LCD-Ausgabe, Zeile 1

      Portc.3 = 1 : Wait 3 : Portc.3 = 0          'LED_rt: 3 s
      Goto M_restart                              'Neustart
   End If

End Sub
'
'-------------------------------------------------------------------------------
'
'optional - LCD-Modul: Ausgabe
'-----------------------------
'Sub Cup_lcd(byval L_code As Byte , Byval L_text As String * 16 )
''Funktion
'   Select Case L_code
'      Case 0
'         Cls                                      'LCD lschen
'         Goto Lcd_end
'      Case 1
'         Upperline
'      Case 2
'         Lowerline
'   End Select

'   Cursor Off                                     'Kursor: Aus
'   Lcd L_text                                     'Textausgabe

'Lcd_end:

'End Sub

'-------------------------------------------------------------------------------
'60. === F U N K T I O N =======================================================
'-------------------------------------------------------------------------------

'entfllt

'-------------------------------------------------------------------------------
'70. === D A T E N B E R E I C H ===============================================
'-------------------------------------------------------------------------------

'entfllt

'Ende

'###############################################################################